# Nextmv Application

This is the basic structure of a Nextmv application.

```text
├── app.yaml
├── README.md
├── requirements.txt
└── src
```

* `app.yaml`: App manifest, containing the configuration to run the app
  remotely on Nextmv Cloud.
* `README.md`: Description of the app.
* `requirements.txt`: Python dependencies for the app.
* `src/`: Source code for the app. The `main.py` file is the entry point for
  the app.
